Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(30)

Unified Diff: tools/bots/run_android_tests.sh

Issue 467643002: Browser testing: Run android content shell tests on hosts with multiple devices connected. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | tools/testing/dart/browser_controller.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/bots/run_android_tests.sh
===================================================================
--- tools/bots/run_android_tests.sh (revision 39141)
+++ tools/bots/run_android_tests.sh (working copy)
@@ -5,9 +5,9 @@
# This script is meant to be run inside the src directory of a Dartium
# (or Chromium) checkout, with android_tools installed in third_party.
-# It expects ContentShell to have been build for ARM android, using the
+# It expects ContentShell to have been built for ARM android, using the
# ninja build system.
# It expects a single android device to be connected by USB to the machine.
set -v
set -x
cd src
@@ -17,17 +17,15 @@
export PATH=$PATH:third_party/android_tools/sdk/platform-tools/\
:third_party/android_tools/sdk/tools/
-adb uninstall org.chromium.content_shell_apk
-adb install -r $1
-./build/android/adb_reverse_forwarder.py 8081 8081 8082 8082 \
- 8083 8083 8084 8084 &
+./build/android/adb_reverse_forwarder.py --all-devices \
+ 8081 8081 8082 8082 8083 8083 8084 8084 &
FORWARDER_PID=$!
sleep 15
./dart/tools/test.py -m release -a arm --progress=line --report --time \
--failure-summary --write-debug-log --local_ip=localhost \
--test_server_port=8083 --test_server_cross_origin_port=8084 \
--test_driver_port=8081 --test_driver_error_port=8082 \
- -r ContentShellOnAndroid
+ -r ContentShellOnAndroid --drt=$1
EXIT_CODE=$?
kill -9 $FORWARDER_PID
exit $EXIT_CODE
@@ -5,9 +5,9 @@
# ninja build system.
-# It expects a single android device to be connected by USB to the machine.
+# It expects one or more android devices to be connected by USB to the machine.
set -v
set -x
« no previous file with comments | « no previous file | tools/testing/dart/browser_controller.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698